@@ -6,24 +6,21 @@ import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
-from gspeerconnection.pitrack import PiH264Relay
+from pitrack import PiH264Relay
 
 
 class GSPeerConnectionWatcher:
-    class PiH264Relay(MediaStreamTrack):
+    class VideoTransformTrack(MediaStreamTrack):
         kind = "video"
-
         def __init__(self, track: RemoteStreamTrack, gsdbs, source, onframe):
             super().__init__()
             self.track = track
             self.onframe = onframe
             self.source = source
             self.gsdbs = gsdbs
-
-        #
         async def recv(self):
-            # frame = await self.track.recv()
-            frame = await self.track._queue.get()
+            frame = await self.track.recv()
+            # frame = await self.track._queue.get()
             # self.onframe(self.gsdbs, self.source, frame)
             return frame
 
@@ -69,11 +66,7 @@ class GSPeerConnectionWatcher:
             def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
-                        self.ontrack(self.gsdbs, track)
-                    # local_video = self.VideoTransformTrack(track, gsdbs=self.gsdbs, source=self.target,
-                    #                                        onframe=self.onframe)
-                    local_video = PiH264Relay(30)
-                    self.peerConnections.addTrack(local_video)
+                        self.ontrack(track)
 
                 @track.on("ended")
                 async def on_ended():
